Card Gift Endpoints
===================

Create a Binance Code (USER_DATA)
---------------------------------
.. autofunction::  binance.spot.Spot.gift_card_create_code

Redeem a Binance Code (USER_DATA)
---------------------------------
.. autofunction::  binance.spot.Spot.gift_card_redeem_code

Verify a Binance Code (USER_DATA)
---------------------------------
.. autofunction::  binance.spot.Spot.gift_card_verify_code

Gift Card RSA Public Key (USER_DATA)
------------------------------------
.. autofunction:: binance.spot.Spot.gift_card_rsa_public_key

Create a dual-token gift card (USER_DATA)
-----------------------------------------
.. autofunction:: binance.spot.Spot.gift_card_buy_code

Fetch Token Limit (USER_DATA)
-----------------------------
.. autofunction:: binance.spot.Spot.gift_card_token_limit
